@@ -31,8 +31,16 @@
 #include "typedefs.h"
 
 
+typedef enum {
+	DESKTOP_ENTRY_TYPE_UNKNOWN,
+	DESKTOP_ENTRY_TYPE_APPLICATION,
+	DESKTOP_ENTRY_TYPE_LINK
+} DesktopEntryType;
+
+
 typedef void (*PathListDoneFunc) (GList *files, GList *dirs, GError *error, gpointer data);
 
+
 gboolean            uri_is_file                   (const char        *uri);
 gboolean            uri_is_dir                    (const char        *uri);
 gboolean            path_is_dir                   (const char        *path);
@@ -67,8 +75,10 @@ gboolean            g_write_file                  (GFile             *file,
 						   gsize              count, 
 						   GCancellable      *cancellable,
 						   GError           **error);
-GKeyFile *          _g_key_file_dup               (GKeyFile          *file);
 void                _g_key_file_cleanup           (GKeyFile          *file);
+GKeyFile *          _g_key_file_dup               (GKeyFile          *file);
+GKeyFile *          _g_desktop_entry_new          (DesktopEntryType   type);
+GKeyFile *          _g_desktop_entry_new_for_uri  (const char        *uri);
 gboolean            _g_desktop_entry_equal        (GKeyFile          *file1,
 						   GKeyFile          *file2);
 void                _g_desktop_entry_launch       (GKeyFile          *desktop_entry,
