@@ -361,7 +361,7 @@ quick_button_expose (GtkWidget         *widget,
 	size = widget->allocation.height;
 	offset = (button->in_button && button->button_down) ? get_displacement (size) : 0;
 	
-	if (button->in_button || GTK_WIDGET_HAS_FOCUS (widget))
+	if (button->in_button || quick_button->dnd_highlight || GTK_WIDGET_HAS_FOCUS (widget))
 		pixbuf = quick_button->scaled_bright;
 	else
 		pixbuf = quick_button->scaled;
@@ -387,13 +387,13 @@ quick_button_expose (GtkWidget         *widget,
 				 GDK_RGB_DITHER_NORMAL,
 				 0, 0);
 	
-	if (quick_button->dnd_highlight) 
+	/*if (quick_button->dnd_highlight) 
 		gdk_draw_rectangle (widget->window, 
 				    widget->style->black_gc, FALSE,
 				    widget->allocation.x, 
 				    widget->allocation.y,
 				    widget->allocation.width - 1,
-				    widget->allocation.height - 1);
+				    widget->allocation.height - 1);*/
 
 	if (GTK_WIDGET_HAS_FOCUS (widget)) {
 		int focus_width, focus_pad;
