@@ -59,8 +59,8 @@
 
 
 enum {
-        REVERT_BUTTON,
-        QUICK_RESPONSE_REVERT
+	REVERT_BUTTON,
+	QUICK_RESPONSE_REVERT
 };
 
 
@@ -91,11 +91,11 @@ properties_verb_cb (BonoboUIComponent *uic,
 	}
 
 	if (quick_lounge->prop_dialog != NULL) {
-                gtk_window_set_screen (GTK_WINDOW (quick_lounge->prop_dialog),
-                                       gtk_widget_get_screen (GTK_WIDGET (quick_lounge->applet)));
+		gtk_window_set_screen (GTK_WINDOW (quick_lounge->prop_dialog),
+				       gtk_widget_get_screen (GTK_WIDGET (quick_lounge->applet)));
 
 		gtk_window_present (GTK_WINDOW (quick_lounge->prop_dialog));
-        }
+	}
 }
 
 
@@ -113,7 +113,7 @@ about_verb_cb (BonoboUIComponent *uic,
 	       QuickLounge       *quick_lounge,
 	       const gchar       *verbname)
 {
-        static GtkWidget *about_dialog = NULL;
+	static GtkWidget *about_dialog = NULL;
 	const char *authors[] = {
 		"Paolo Bacchilega <paolo.bacchilega@libero.it>",
 		NULL
@@ -124,31 +124,31 @@ about_verb_cb (BonoboUIComponent *uic,
 	};
 	const char *translator_credits = _("translator_credits");
 
-        if (about_dialog) {
-                gtk_window_set_screen (GTK_WINDOW (about_dialog),
-                                       gtk_widget_get_screen (GTK_WIDGET (quick_lounge->applet)));
-                gtk_window_present (GTK_WINDOW (about_dialog));
-                return;
-        }
+	if (about_dialog) {
+		gtk_window_set_screen (GTK_WINDOW (about_dialog),
+				       gtk_widget_get_screen (GTK_WIDGET (quick_lounge->applet)));
+		gtk_window_present (GTK_WINDOW (about_dialog));
+		return;
+	}
 
-        about_dialog = gtk_about_dialog_new ();
+	about_dialog = gtk_about_dialog_new ();
 
-        g_object_set (about_dialog,
+	g_object_set (about_dialog,
 		      "name", _("Launchers List"),
-	              "version", VERSION,
+		      "version", VERSION,
 		      "copyright", "Copyright \xc2\xa9 2002-2009 Free Software Foundation, Inc.",
-	              "comments", _("Organize your favorite applications on the Panel"),
-	              "authors", authors,
-	              "documenters", documenters,
-    	              "translator-credits", strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-	              "logo-icon-name", "quick-lounge-applet",
-	              NULL);
+		      "comments", _("Organize your favorite applications on the Panel"),
+		      "authors", authors,
+		      "documenters", documenters,
+			  "translator-credits", strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+		      "logo-icon-name", "quick-lounge-applet",
+		      NULL);
 
 	gtk_window_set_wmclass (GTK_WINDOW (about_dialog), "quick-lounge-applet", "Quick-lounge-applet");
-        gtk_window_set_screen (GTK_WINDOW (about_dialog), gtk_widget_get_screen (GTK_WIDGET (quick_lounge->applet)));
+	gtk_window_set_screen (GTK_WINDOW (about_dialog), gtk_widget_get_screen (GTK_WIDGET (quick_lounge->applet)));
 	g_signal_connect (about_dialog, "destroy", G_CALLBACK (gtk_widget_destroyed), &about_dialog);
 	g_signal_connect (about_dialog, "response", G_CALLBACK (gtk_widget_destroy), NULL);
-        gtk_widget_show (about_dialog);
+	gtk_widget_show (about_dialog);
 
 }
 static const BonoboUIVerb menu_verbs [] = {
@@ -166,7 +166,7 @@ applet_destroy (GtkWidget    *applet,
 	/* free memory */
 
 	if (quick_lounge->prop_dialog != NULL)
-                gtk_widget_destroy (quick_lounge->prop_dialog);
+		gtk_widget_destroy (quick_lounge->prop_dialog);
 
 	g_free (quick_lounge->location);
 	g_object_unref (quick_lounge->icon_theme);
@@ -176,11 +176,11 @@ applet_destroy (GtkWidget    *applet,
 
 static void
 applet_change_orient (PanelApplet       *applet,
-                      PanelAppletOrient  orientation,
-                      QuickLounge       *quick_lounge)
+		      PanelAppletOrient  orientation,
+		      QuickLounge       *quick_lounge)
 {
-        if (quick_lounge->orientation == orientation)
-                return;
+	if (quick_lounge->orientation == orientation)
+		return;
 	quick_lounge->orientation = orientation;
 	quick_box_set_orient (quick_lounge->quick_box, orientation);
 }
@@ -188,8 +188,8 @@ applet_change_orient (PanelApplet       *applet,
 
 static void
 applet_change_size (PanelApplet   *applet,
-                    int            size,
-                    QuickLounge   *quick_lounge)
+		    int            size,
+		    QuickLounge   *quick_lounge)
 {
 	if (quick_lounge->size != size) {
 		quick_lounge->size = size;
@@ -200,10 +200,10 @@ applet_change_size (PanelApplet   *applet,
 
 static void
 applet_change_background (PanelApplet               *applet,
-                          PanelAppletBackgroundType  type,
-                          GdkColor                  *color,
-                          GdkPixmap                 *pixmap,
-                          QuickLounge               *quick_lounge)
+			  PanelAppletBackgroundType  type,
+			  GdkColor                  *color,
+			  GdkPixmap                 *pixmap,
+			  QuickLounge               *quick_lounge)
 {
 	/* taken from the Trash Applet */
 	GtkRcStyle *rc_style;
@@ -240,18 +240,18 @@ applet_change_background (PanelApplet               *applet,
 
 static void
 applet_size_request (GtkWidget      *widget,
-                     GtkRequisition *requisition,
-                     QuickLounge    *quick_lounge)
+		     GtkRequisition *requisition,
+		     QuickLounge    *quick_lounge)
 {
 	GtkRequisition  child_req;
-        const int      *size_hints;
+	const int      *size_hints;
 	int             len;
 
 	gtk_widget_get_child_requisition (quick_lounge->applet, &child_req);
 	size_hints = quick_box_get_size_hint_list (quick_lounge->quick_box, &len);
 	panel_applet_set_size_hints (PANEL_APPLET (quick_lounge->applet),
-                                     size_hints,
-                                     len,
+				     size_hints,
+				     len,
 				     child_req.width);
 }
 
@@ -296,7 +296,7 @@ static void
 edit_desktop_entry_dialog_destroy_cb (GtkWidget *widget,
 				      gpointer   user_data)
 {
-        g_free (user_data);
+	g_free (user_data);
 }
 
 
@@ -307,17 +307,17 @@ edit_desktop_entry_dialog_response_cb (GtkDialog *dialog,
 {
 	switch (response) {
 	case GTK_RESPONSE_HELP:
-        	_gtk_show_help (NULL, "user-guide", "gospanel-52");
-        	break;
-        
-        case QUICK_RESPONSE_REVERT:
+		_gtk_show_help (NULL, "user-guide", "gospanel-52");
+		break;
+
+	case QUICK_RESPONSE_REVERT:
 		quick_desktop_entry_dialog_revert (QUICK_DESKTOP_ENTRY_DIALOG (dialog));
 		break;
-	
+
 	case GTK_RESPONSE_CLOSE:
 		gtk_widget_destroy (GTK_WIDGET (dialog));
 		break;
-		
+
 	default:
 		break;
 	}
@@ -337,35 +337,35 @@ edit_desktop_entry_dialog_changed_cb (GtkDialog *dialog,
 	gsize          length;
 	const char    *uri;
 	GFile         *file;
-	
+
 	gtk_dialog_set_response_sensitive (dialog, QUICK_RESPONSE_REVERT, ! reverted);
-	
+
 	desktop_entry = quick_desktop_entry_dialog_get_entry (QUICK_DESKTOP_ENTRY_DIALOG (dialog), &error);
 	if (error != NULL) {
 		_gtk_error_dialog_from_gerror_run (GTK_WINDOW (dialog), _("Could not save the launcher"), &error);
 		return;
 	}
-	
+
 	if (desktop_entry == NULL)
 		return;
-	
+
 	data = g_key_file_to_data (desktop_entry, &length, &error);
 	if (data == NULL) {
 		g_key_file_free (desktop_entry);
 		_gtk_error_dialog_from_gerror_run (GTK_WINDOW (dialog), _("Could not save the launcher"), &error);
 		return;
-	} 
-	
+	}
+
 	uri = g_object_get_data (G_OBJECT (edit_data->button), "uri");
 	file = g_file_new_for_uri (uri);
-	if (! g_write_file (file, FALSE, G_FILE_CREATE_NONE, data, length, NULL, &error)) { 
+	if (! g_write_file (file, FALSE, G_FILE_CREATE_NONE, data, length, NULL, &error)) {
 		_gtk_error_dialog_from_gerror_run (GTK_WINDOW (dialog), _("Could not save the launcher"), &error);
 	}
 	else {
 		quick_box_update_child (edit_data->quick_lounge->quick_box, (QuickButton*) button, desktop_entry);
 		dlg_properties_update (edit_data->quick_lounge->prop_dialog);
 	}
-	
+
 	g_object_unref (file);
 	g_free (data);
 	g_key_file_free (desktop_entry);
@@ -379,13 +379,13 @@ quick_lounge_util__item_properties (QuickLounge *quick_lounge,
 	EditItemData *data;
 	GtkWidget    *dialog;
 	GKeyFile     *desktop_entry;
-	
+
 	data = g_new0 (EditItemData, 1);
-	data->quick_lounge = quick_lounge;	
+	data->quick_lounge = quick_lounge;
 	data->button = button;
-	
+
 	desktop_entry = g_object_get_data (G_OBJECT (button), "desktop_entry");
-	
+
 	dialog = quick_desktop_entry_dialog_new (_("Launcher Properties"), NULL, desktop_entry);
 	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_HELP, GTK_RESPONSE_HELP);
 	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_REVERT_TO_SAVED, QUICK_RESPONSE_REVERT);
@@ -394,20 +394,21 @@ quick_lounge_util__item_properties (QuickLounge *quick_lounge,
 	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), QUICK_RESPONSE_REVERT, FALSE);
 
 	g_signal_connect (dialog,
-                          "destroy",
-                          G_CALLBACK (edit_desktop_entry_dialog_destroy_cb),
-                          data);
-        g_signal_connect (dialog, 
-        		  "response",
-                          G_CALLBACK (edit_desktop_entry_dialog_response_cb),
-                          data);
-	g_signal_connect (dialog, 
+			  "destroy",
+			  G_CALLBACK (edit_desktop_entry_dialog_destroy_cb),
+			  data);
+	g_signal_connect (dialog,
+			  "response",
+			  G_CALLBACK (edit_desktop_entry_dialog_response_cb),
+			  data);
+	g_signal_connect (dialog,
 			  "changed",
-                          G_CALLBACK (edit_desktop_entry_dialog_changed_cb),
-                          data);
+			  G_CALLBACK (edit_desktop_entry_dialog_changed_cb),
+			  data);
 
-        gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
-        gtk_window_present (GTK_WINDOW (dialog));
+	gtk_window_set_screen (GTK_WINDOW (dialog), gtk_widget_get_screen (GTK_WIDGET (quick_lounge->applet)));
+	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
+	gtk_window_present (GTK_WINDOW (dialog));
 }
 
 
@@ -489,10 +490,10 @@ quick_lounge_add_launcher (QuickLounge  *quick_lounge,
 	gsize     length;
 	char     *uri;
 	GFile    *file;
-	
+
 	if (desktop_entry == NULL)
 		return FALSE;
-	
+
 	data = g_key_file_to_data (desktop_entry, &length, &error);
 	if (data == NULL) {
 		g_key_file_free (desktop_entry);
@@ -502,11 +503,11 @@ quick_lounge_add_launcher (QuickLounge  *quick_lounge,
 				       error->message);
 		g_clear_error (&error);
 		return FALSE;
-	} 
-	
+	}
+
 	uri = quick_lounge_util__get_unique_uri (quick_lounge);
 	file = g_file_new_for_uri (uri);
-	if (! g_write_file (file, FALSE, G_FILE_CREATE_NONE, data, length, NULL, &error)) { 
+	if (! g_write_file (file, FALSE, G_FILE_CREATE_NONE, data, length, NULL, &error)) {
 		_gtk_error_dialog_run (NULL,
 				       ERROR_FORMAT,
 				       _("Could not create the new launcher"),
@@ -517,11 +518,11 @@ quick_lounge_add_launcher (QuickLounge  *quick_lounge,
 		quick_box_add_button (quick_lounge->quick_box, uri, position);
 		launcher_added = TRUE;
 	}
-	
+
 	g_object_unref (file);
 	g_free (uri);
 	g_free (data);
-	
+
 	return launcher_added;
 }
 
@@ -534,23 +535,23 @@ new_desktop_entry_dialog_response_cb (GtkDialog *dialog,
 	EditItemData *edit_data = user_data;
 	GKeyFile     *desktop_entry;
 	GError       *error = NULL;
-		
+
 	switch (response) {
 	case GTK_RESPONSE_HELP:
-        	_gtk_show_help (NULL, "user-guide", "gospanel-52");
-        	break;
-        
+		_gtk_show_help (NULL, "user-guide", "gospanel-52");
+		break;
+
 	case GTK_RESPONSE_CANCEL:
 		gtk_widget_destroy (GTK_WIDGET (dialog));
 		break;
-		
+
 	default:
 		break;
 	}
-	
+
 	if (response != GTK_RESPONSE_OK)
 		return;
-	
+
 	desktop_entry = quick_desktop_entry_dialog_get_entry (QUICK_DESKTOP_ENTRY_DIALOG (dialog), &error);
 	if (error != NULL) {
 		_gtk_error_dialog_run (NULL,
@@ -560,13 +561,13 @@ new_desktop_entry_dialog_response_cb (GtkDialog *dialog,
 		g_clear_error (&error);
 		return;
 	}
-	
+
 	if (quick_lounge_add_launcher (edit_data->quick_lounge, desktop_entry, edit_data->position + 1)) {
 		quick_lounge_save_order (edit_data->quick_lounge);
 		dlg_properties_update (edit_data->quick_lounge->prop_dialog);
 		gtk_widget_destroy (GTK_WIDGET (dialog));
 	}
-	
+
 	g_key_file_free (desktop_entry);
 }
 
@@ -577,27 +578,28 @@ quick_lounge_new_launcher (QuickLounge *quick_lounge,
 {
 	EditItemData *data;
 	GtkWidget    *dialog;
-	
+
 	data = g_new0 (EditItemData, 1);
-	data->quick_lounge = quick_lounge;	
+	data->quick_lounge = quick_lounge;
 	data->position = position;
-	
+
 	dialog = quick_desktop_entry_dialog_new (_("New Launcher"), NULL, NULL);
 	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_HELP, GTK_RESPONSE_HELP);
 	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_OK, GTK_RESPONSE_OK);
 
 	g_signal_connect (dialog,
-                          "destroy",
-                          G_CALLBACK (edit_desktop_entry_dialog_destroy_cb),
-                          data);
-        g_signal_connect (dialog, 
-        		  "response",
-                          G_CALLBACK (new_desktop_entry_dialog_response_cb),
-                          data);
+			  "destroy",
+			  G_CALLBACK (edit_desktop_entry_dialog_destroy_cb),
+			  data);
+	g_signal_connect (dialog,
+			  "response",
+			  G_CALLBACK (new_desktop_entry_dialog_response_cb),
+			  data);
 
-        gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
-        gtk_window_present (GTK_WINDOW (dialog));
+	gtk_window_set_modal (GTK_WINDOW (dialog), TRUE);
+	gtk_window_set_screen (GTK_WINDOW (dialog), gtk_widget_get_screen (GTK_WIDGET (quick_lounge->applet)));
+	gtk_window_present (GTK_WINDOW (dialog));
 }
 
 
@@ -727,7 +729,7 @@ populate_context_menu (GtkWidget *popup_menu,
 				  "activate",
 				  G_CALLBACK (add_from_menu_cb),
 				  button);
-	
+
 	/**/
 
 	item = gtk_image_menu_item_new_with_mnemonic (_("_New Launcher"));
@@ -778,7 +780,6 @@ populate_context_menu (GtkWidget *popup_menu,
 				  "activate",
 				  G_CALLBACK (item_move_cb),
 				  button);
-
 }
 
 
@@ -786,8 +787,8 @@ populate_context_menu (GtkWidget *popup_menu,
 
 
 static void
-open_file_list_with_launcher (QuickLounge *quick_lounge, 
-			      int          pos, 
+open_file_list_with_launcher (QuickLounge *quick_lounge,
+			      int          pos,
 			      GList       *list)
 {
 	GtkWidget *button;
@@ -795,7 +796,7 @@ open_file_list_with_launcher (QuickLounge *quick_lounge,
 
 	button = quick_box_get_child_at_pos (quick_lounge->quick_box, pos);
 	if (button == NULL)
-		return; 
+		return;
 
 	desktop_entry = g_object_get_data (G_OBJECT (button), "desktop_entry");
 	if (desktop_entry != NULL)
@@ -815,15 +816,15 @@ drag_data_received  (GtkWidget          *widget,
 {
 	QuickLounge  *quick_lounge = extra_data;
 	QuickBox     *quick_box = QUICK_BOX (widget);
-        GList        *list, *scan;
+	GList        *list, *scan;
 	int           pos;
 	QuickDropPos  drop_position;
 	gboolean      launcher_list_changed = FALSE;
-	
-        if (! ((data->length >= 0) && (data->format == 8))) {
-                gtk_drag_finish (context, FALSE, FALSE, time);
-                return;
-        }
+
+	if (! ((data->length >= 0) && (data->format == 8))) {
+		gtk_drag_finish (context, FALSE, FALSE, time);
+		return;
+	}
 
 	gtk_drag_finish (context, TRUE, FALSE, time);
 
@@ -833,7 +834,7 @@ drag_data_received  (GtkWidget          *widget,
 	if ((drop_position == QUICK_DROP_POSITION_INTO_OR_BEFORE)
 	    || (drop_position == QUICK_DROP_POSITION_INTO_OR_AFTER))
 	{
-		if (! is_desktop_file (list->data)) { 
+		if (! is_desktop_file (list->data)) {
 			open_file_list_with_launcher (quick_lounge, pos, list);
 			path_list_free (list);
 			return;
@@ -845,21 +846,21 @@ drag_data_received  (GtkWidget          *widget,
 	{
 		pos++;
 	}
-	
+
 	for (scan = list; scan; scan = scan->next) {
 		char *src_uri = scan->data;
-			
-		if (is_desktop_file (src_uri)) { 
+
+		if (is_desktop_file (src_uri)) {
 			char      *uri;
 			GtkWidget *button;
 
 			uri = g_build_filename (quick_lounge->location,
 						file_name_from_path (src_uri),
 						NULL);
-	
+
 			if (strcmp (src_uri, uri) == 0) {
 				button = quick_box_get_child_from_uri (quick_box, uri);
-	
+
 				if (button != NULL) {
 					int button_pos;
 					button_pos = quick_box_get_child_position (quick_box, button);
@@ -868,35 +869,35 @@ drag_data_received  (GtkWidget          *widget,
 						launcher_list_changed = TRUE;
 					}
 				}
-	
+
 				g_free (uri);
 				continue;
 			}
-	
+
 			g_free (uri);
 			uri = quick_lounge_util__get_unique_uri (quick_lounge);
-	
+
 			if (! file_copy (src_uri, uri)) {
 				g_free (uri);
 				continue;
 			}
-	
+
 			quick_box_add_button (quick_box, uri, pos++);
 			launcher_list_changed = TRUE;
-			
+
 			g_free (uri);
 		}
 		else {
 			GKeyFile *desktop_entry;
-				
+
 			desktop_entry = _g_desktop_entry_new_for_uri (src_uri);
-			if (quick_lounge_add_launcher (quick_lounge, desktop_entry, pos)) 
+			if (quick_lounge_add_launcher (quick_lounge, desktop_entry, pos))
 				launcher_list_changed = TRUE;
-						
+
 			g_key_file_free (desktop_entry);
 		}
 	}
-	
+
 	if (launcher_list_changed) {
 		quick_lounge_save_order (quick_lounge);
 		dlg_properties_update (quick_lounge->prop_dialog);
@@ -919,7 +920,7 @@ quick_lounge_save_order (QuickLounge *quick_lounge)
 	for (scan = children; scan; scan = scan->next) {
 		GtkWidget *child_widget = scan->data;
 		char      *uri;
-		
+
 		if (QUICK_IS_SEPARATOR (child_widget)) {
 			uri_list = g_slist_prepend (uri_list, g_strdup (""));
 			continue;
@@ -1184,7 +1185,7 @@ quick_lounge_set_min_visible_cols (QuickLounge *quick_lounge,
 				   int          value)
 {
 	gboolean needs_update = FALSE;
-	
+
 	if (value == quick_box_get_min_visible_cols (quick_lounge->quick_box))
 		return FALSE;
 	if (value < 0)
@@ -1198,13 +1199,13 @@ quick_lounge_set_min_visible_cols (QuickLounge *quick_lounge,
 					    NULL);
 		needs_update = TRUE;
 	}
-	
+
 	quick_box_set_min_visible_cols (quick_lounge->quick_box, value);
 	panel_applet_gconf_set_int (PANEL_APPLET (quick_lounge->applet),
 				    PREFS_MIN_VISIBLE_COLS,
 				    value,
 				    NULL);
-			
+
 	return needs_update;
 }
 
@@ -1228,7 +1229,7 @@ quick_lounge_set_max_size (QuickLounge *quick_lounge,
 					    NULL);
 		needs_update = TRUE;
 	}
-	
+
 	quick_box_set_max_visible_cols (quick_lounge->quick_box, value);
 	panel_applet_gconf_set_int (PANEL_APPLET (quick_lounge->applet),
 				    PREFS_MAX_VISIBLE_COLS,
@@ -1259,14 +1260,14 @@ quick_lounge_set_rows (QuickLounge *quick_lounge,
 static char *
 get_unique_dirname (void)
 {
-        static int  n = 0;
+	static int  n = 0;
 	char       *base_dir;
 	char       *unique_dir = NULL;
 
 	base_dir = g_build_filename (g_get_home_dir (), BASE_DIR, NULL);
 	make_directory_tree_from_path (base_dir, 0700, NULL);
 
-        while (unique_dir == NULL) {
+	while (unique_dir == NULL) {
 		char     *path;
 		char     *name;
 		gboolean  exists;
@@ -1398,8 +1399,8 @@ quick_lounge_applet_fill (PanelApplet *applet)
 				      quick_lounge);
 
 	gtk_drag_dest_set (GTK_WIDGET (quick_lounge->quick_box),
-                           GTK_DEST_DEFAULT_ALL,
-                           target_table, G_N_ELEMENTS (target_table),
+			   GTK_DEST_DEFAULT_ALL,
+			   target_table, G_N_ELEMENTS (target_table),
 			   GDK_ACTION_COPY | GDK_ACTION_MOVE);
 
 	g_signal_connect (G_OBJECT (quick_lounge->quick_box),
@@ -1451,18 +1452,18 @@ quick_lounge_applet_fill (PanelApplet *applet)
 
 	g_signal_connect (G_OBJECT (applet),
 			  "destroy",
-                          G_CALLBACK (applet_destroy),
-                          quick_lounge);
+			  G_CALLBACK (applet_destroy),
+			  quick_lounge);
 
 	g_signal_connect (G_OBJECT (applet),
-                          "change_orient",
-                          G_CALLBACK (applet_change_orient),
-                          quick_lounge);
+			  "change_orient",
+			  G_CALLBACK (applet_change_orient),
+			  quick_lounge);
 
-        g_signal_connect (G_OBJECT (applet),
-                          "change_size",
-                          G_CALLBACK (applet_change_size),
-                          quick_lounge);
+	g_signal_connect (G_OBJECT (applet),
+			  "change_size",
+			  G_CALLBACK (applet_change_size),
+			  quick_lounge);
 
 	g_signal_connect (G_OBJECT (applet),
 			  "change_background",
@@ -1470,13 +1471,13 @@ quick_lounge_applet_fill (PanelApplet *applet)
 			  quick_lounge);
 	g_signal_connect (G_OBJECT (applet),
 			  "size_request",
-                          G_CALLBACK (applet_size_request),
-                          quick_lounge);
+			  G_CALLBACK (applet_size_request),
+			  quick_lounge);
 
 	g_signal_connect (G_OBJECT (applet),
 			  "size_allocate",
-                          G_CALLBACK (applet_size_allocate),
-                          quick_lounge);
+			  G_CALLBACK (applet_size_allocate),
+			  quick_lounge);
 
 	panel_applet_setup_menu_from_file (applet,
 					   NULL,
@@ -1500,10 +1501,10 @@ quick_lounge_factory (PanelApplet *applet,
 		      const  char *iid,
 		      gpointer     data)
 {
-        if (strcmp (iid, APPLET_IID) == 0)
+	if (strcmp (iid, APPLET_IID) == 0)
 		return quick_lounge_applet_fill (applet);
 
-        return FALSE;
+	return FALSE;
 }
 
 
