@@ -53,7 +53,10 @@ void	  quick_lounge_set_rows			   (QuickLounge  *quick_lounge,
 						    int		  value);
 void      quick_lounge_new_launcher                (QuickLounge  *quick_lounge,
 						    int           pos);
-
+gboolean  quick_lounge_add_launcher                (QuickLounge  *quick_lounge,
+						    GKeyFile     *desktop_entry,
+						    int           pos);
+						    
 /* utils */
 
 void    quick_lounge_util__item_properties         (QuickLounge  *quick_lounge,
